@@ -1,9 +1,5 @@
-import json
 import requests
-
-from intellifire4py.intellifirepolldata import IntellifirePollData
-
-
+from .model import IntellifirePollData
 
 class Intellifire:
 
@@ -13,9 +9,16 @@ class Intellifire:
         self.__data: IntellifirePollData = None
 
     def poll(self):
-        response = requests.get("http://" + self.ip + "/poll")
-        print(response.json())
-        self.__data = IntellifirePollData(**response.json())
+        try:
+            response = requests.get("http://" + self.ip + "/poll")
+            if response.status_code == 404:
+                # Valid address - but poll endpoint not found
+                raise ConnectionError("Fireplace Endpoint Not Found - 404")
+
+            # print(response.json())
+            self.__data = IntellifirePollData(**response.json())
+        except ConnectionError as e:
+            raise ConnectionError("ConnectionError - host not found")
 
     @property
     def data(self) -> IntellifirePollData:
@@ -27,8 +30,6 @@ def main():
     fire = Intellifire("192.168.1.80")
     # Poll the fire
     fire.poll()
-
-
     print(f"{fire.data.temperature_c} c")
     print(f"{fire.data.temperature_f} f")
 
